package com.atguigu.interceptor;

import com.alibaba.fastjson.JSON;
import com.atguigu.context.BaseContext;
import com.atguigu.spzx.model.entity.system.SysUser;
import com.atguigu.utils.InterceptorUtil;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.lang.NonNull;
import org.springframework.lang.Nullable;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.HandlerInterceptor;

import java.util.concurrent.TimeUnit;

@Configuration
@Slf4j
public class LoginAuthInterceptor implements HandlerInterceptor {
    @Autowired
    RedisTemplate<String, Object> redisTemplate;

    @Override
    public boolean preHandle(@NonNull HttpServletRequest request, @NonNull HttpServletResponse response, @NonNull Object handler) throws Exception {
        String method = request.getMethod();
        String token = request.getHeader("token");

        // 判断当前拦截到的是Controller方法还是其它资源
        if ("OPTIONS".equals(method) || !(handler instanceof HandlerMethod)) return true;

        // 当前token为空
        if (StringUtils.isEmpty(token)) {
            InterceptorUtil.unLoginInterceptor(response);
            return false;
        }

        // 获取用户信息不存在
        Object sysUserObject = redisTemplate.opsForValue().get(token);
        String sysUserString = JSON.toJSONString(sysUserObject);
        if (sysUserObject == null) {
            InterceptorUtil.unLoginInterceptor(response);
            return false;
        }

        // 将用户信息放到ThreadLocal中
        BaseContext.setSysUser(JSON.parseObject(sysUserString, SysUser.class));

        // 更新Redis过期时间
        redisTemplate.expire(token, 7, TimeUnit.DAYS);

        // 放行
        return true;
    }

    /**
     * 请求完成后删除ThreadLocal
     */
    @Override
    public void afterCompletion(@NonNull HttpServletRequest request, @NonNull HttpServletResponse response, @NonNull Object handler, @Nullable Exception ex) throws Exception {
        BaseContext.removeSysUser();
    }
}
