package com.atguigu.spzx.manger.controller;

import com.atguigu.context.BaseContext;
import com.atguigu.spzx.manger.service.SysUserService;
import com.atguigu.spzx.manger.service.ValidateCodeService;
import com.atguigu.spzx.model.dto.system.LoginDto;
import com.atguigu.spzx.model.entity.system.SysUser;
import com.atguigu.spzx.model.vo.result.Result;
import com.atguigu.spzx.model.vo.system.LoginVo;
import com.atguigu.spzx.model.vo.system.ValidateCodeVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Tag(name = "用户相关接口")
@RestController
@RequestMapping("/admin/system/index")
public class IndexController {
    @Autowired
    private SysUserService sysUserService;
    @Autowired
    private ValidateCodeService validateCodeService;

    @Operation(summary = "生成验证码", description = "生成验证码信息")
    @GetMapping("generateValidateCode")
    public Result<ValidateCodeVo> generateValidateCode() {
        ValidateCodeVo vo = validateCodeService.generateValidateCode();
        return Result.success(vo);
    }

    @Operation(summary = "登录请求", description = "登录请求实现")
    @PostMapping("login")
    public Result<LoginVo> login(@RequestBody LoginDto loginDto) {
        LoginVo vo = sysUserService.login(loginDto);
        return Result.success(vo);
    }

    @Operation(summary = "获取登录用户信息", description = "获取当前登录用户信息")
    @GetMapping("getUserInfo")
    public Result<SysUser> getUserInfo() {
        SysUser sysUser = BaseContext.getSysUser();
        return Result.success(sysUser);
    }

    @Operation(summary = "用户退出", description = "用户退出接口")
    @GetMapping(value = "/logout")
    public Result logout(@RequestHeader(value = "token") String token) {
        sysUserService.logout(token);
        return Result.success();
    }
}
