package com.atguigu.spzx.manger.service.impl;

import com.atguigu.constant.MessageConstant;
import com.atguigu.spzx.manger.mapper.SysRoleMapper;
import com.atguigu.spzx.manger.mapper.SysRoleUserMapper;
import com.atguigu.spzx.manger.service.SysRoleService;
import com.atguigu.spzx.model.dto.system.AssginRoleDto;
import com.atguigu.spzx.model.dto.system.SysRoleDto;
import com.atguigu.spzx.model.entity.system.SysRole;
import com.atguigu.spzx.model.vo.system.AllRolesVo;
import com.atguigu.utils.StringEmptyUtil;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class SysRoleServiceImpl implements SysRoleService {
    @Autowired
    private SysRoleMapper sysRoleMapper;
    @Autowired
    private SysRoleUserMapper sysRoleUserMapper;
    @Autowired
    private StringEmptyUtil emptyUtil;

    /**
     * 查询角色信息返回分页
     *
     * @param sysRoleDto 请求参数实体类
     * @param pageNum    当前也
     * @param pageSize   分页大小
     * @return 返回分页结果
     */
    @Override
    public PageInfo<SysRole> findByPage(SysRoleDto sysRoleDto, Integer pageNum, Integer pageSize) {
        Page<Object> startedPage = PageHelper.startPage(pageNum, pageSize);
        List<SysRole> sysRoles = sysRoleMapper.findByPage(sysRoleDto);
        PageInfo<SysRole> pageInfo = new PageInfo<>(sysRoles);
        startedPage.close();
        return pageInfo;
    }

    /**
     * 添加角色相关内容
     *
     * @param sysRole 角色实体类
     */
    @Override
    public void saveSysRole(SysRole sysRole) {
        sysRoleMapper.saveSysRole(sysRole);
    }

    /**
     * 修改角色相关信息
     *
     * @param sysRole 角色实体类
     */
    @Override
    public void updateSysRole(SysRole sysRole) {
        emptyUtil.isEmpty(sysRole.getId(), MessageConstant.UPDATE_ID_IS_NOT_EMPTY);

        // 修改内容
        sysRoleMapper.updateSysRole(sysRole);
    }

    /**
     * 根据角色id删除角色
     *
     * @param roleId 角色id
     */
    @Override
    public void deleteById(Long roleId) {
        emptyUtil.isEmpty(roleId, MessageConstant.DELETE_ID_IS_NOT_EMPTY);
        // 删除内容
        sysRoleMapper.deleteById(roleId);
    }

    /**
     * 查询所有角色
     *
     * @return 所有角色信息
     */
    @Override
    public AllRolesVo findAllRoles() {
        List<SysRole> sysRoleList = sysRoleMapper.findAllRoles();
        return AllRolesVo.builder().allRolesList(sysRoleList).build();
    }

    /**
     * 保存角色数据
     *
     * @param assginRoleDto 请求参数实体类
     */
    @Override
    public void doAssign(AssginRoleDto assginRoleDto) {
        // 删除之前的所有的用户所对应的角色数据
        sysRoleUserMapper.deleteByUserId(assginRoleDto.getUserId());
        // 分配新的角色数据
        assginRoleDto.getRoleIdList().forEach(roleId -> {
            sysRoleUserMapper.doAssign(assginRoleDto.getUserId(), roleId);
        });
    }
}
